@@ -94,7 +94,7 @@ def plot_graph(gin, plotpath='/tmp/mygraph.png', inverty=False, ax='', shppath='
             xattr = 'x'; yattr = 'y'
 
     if inverty:
-        g.vs[yattr] = - g.vs[yattr]
+        g.vs[yattr] = (- np.array(g.vs[yattr])).tolist()
 
     vcoords = np.array([(x, y) for x, y in zip(g.vs[xattr], g.vs[yattr])])
     vcoords = vcoords.astype(float)
